@@ -214,7 +214,7 @@ class AdminImageWidget(AdminFileWidget):
 
 class BaseModelAdmin(admin.ModelAdmin):
     """
-    default Admin class used by proxy|real models
+    自定义Admin基类，列表页显示默认字段，支持自定义功能
     """
 
     # remove "__str__"
@@ -263,7 +263,7 @@ class BaseModelAdmin(admin.ModelAdmin):
         return self.__getattribute__(attr)
 
     def formfield_for_dbfield(self, db_field, **kwargs):
-        if isinstance(db_field, models.ImageField):
+        if cool_settings.ADMIN_SHOW_IMAGE_IN_FORM_PAGE and isinstance(db_field, models.ImageField):
             kwargs.pop("request", None)
             kwargs['widget'] = AdminImageWidget
             return db_field.formfield(**kwargs)
@@ -294,7 +294,7 @@ class BaseModelAdmin(admin.ModelAdmin):
     def formfield_for_foreignkey(self, db_field, request, **kwargs):
         db = kwargs.get('using')
         if ('widget' not in kwargs
-                and cool_settings.FOREIGNKEY_FIELD_USE_AUTOCOMPLETE
+                and cool_settings.ADMIN_FOREIGNKEY_FIELD_USE_AUTOCOMPLETE
                 and hasattr(db_field.remote_field.model, 'get_search_fields')
                 and db_field.name not in [*self.raw_id_fields, *self.radio_fields]):
             kwargs['widget'] = widgets.CoolAutocompleteSelect(db_field.remote_field, self.admin_site, using=db)
@@ -303,7 +303,7 @@ class BaseModelAdmin(admin.ModelAdmin):
     def formfield_for_manytomany(self, db_field, request, **kwargs):
         db = kwargs.get('using')
         if ('widget' not in kwargs
-                and cool_settings.MANYTOMANY_FIELD_USE_AUTOCOMPLETE
+                and cool_settings.ADMIN_MANYTOMANY_FIELD_USE_AUTOCOMPLETE
                 and hasattr(db_field.remote_field.model, 'get_search_fields')
                 and db_field.name not in [*self.raw_id_fields, *self.filter_vertical, *self.filter_horizontal]):
             kwargs['widget'] = widgets.CoolAutocompleteSelectMultiple(db_field.remote_field, self.admin_site, using=db)
@@ -485,7 +485,7 @@ class BaseModelAdmin(admin.ModelAdmin):
         tails = []
 
         def _get_field(field_name):
-            if not field_name or not isinstance(field_name, str):
+            if not field_name or not isinstance(field_name, str) or not cool_settings.ADMIN_SHOW_IMAGE_IN_CHANGE_LIST:
                 return field_name
             try:
                 field = self.model._meta.get_field(field_name)
@@ -569,13 +569,13 @@ def check_perms(*perms):
 
     def inner(func):
         @wraps(func)
-        def wrapper(admin, request, *args, **kwargs):
-            opts = admin.opts
+        def wrapper(_admin, request, *args, **kwargs):
+            opts = _admin.opts
             for perm in perms:
                 codename = get_permission_codename(perm, opts)
                 if not request.user.has_perm("%s.%s" % (opts.app_label, codename)):
                     raise PermissionDenied
-            return func(admin, request, *args, **kwargs)
+            return func(_admin, request, *args, **kwargs)
 
         return wrapper
 
@@ -588,3 +588,35 @@ def site_register(model_or_iterable, admin_class=None, site=None, **options):
     if admin_class is None:
         admin_class = BaseModelAdmin
     site.register(model_or_iterable, admin_class, **options)
+
+
+def admin_register(func=None, *, admin_class=None, site=None, **options):
+    """
+    Register the given model(s) classes and wrapped ModelAdmin class with
+    admin site:
+
+    @admin_register()
+    class Author(models.BaseModel):
+        pass
+
+    The `site` kwarg is an admin site to use instead of the default admin site.
+    """
+
+    def _model_admin_wrapper(model_class):
+
+        if site is not None and not isinstance(site, admin.AdminSite):
+            raise ValueError('site must subclass AdminSite')
+
+        if admin_class is not None and not issubclass(admin_class, admin.ModelAdmin):
+            raise ValueError('admin_class must subclass ModelAdmin.')
+
+        if model_class is None or not issubclass(model_class, models.Model):
+            raise ValueError('Wrapped class must subclass Model.')
+
+        site_register(model_class, admin_class=admin_class, site=site, **options)
+        return model_class
+
+    if func is None:
+        return _model_admin_wrapper
+    else:
+        return _model_admin_wrapper(func)
