@@ -3,6 +3,7 @@ from __future__ import absolute_import, unicode_literals
 
 import json
 import logging
+import time
 from collections import OrderedDict
 
 from django.conf import settings
@@ -28,11 +29,9 @@ from cool.views.options import ViewMetaclass, ViewOptions
 from cool.views.param import Param
 from cool.views.response import ResponseData
 
-logger = logging.getLogger('cool.views')
-
 
 class ParamSerializer(serializers.Serializer):
-    def __init__(self, instance=None, data=empty, files=None, **kwargs):
+    def __init__(self, instance=None, data=empty, files=None, is_form=True, **kwargs):
         d = MultiValueDict()
         if data is not empty:
             d.update(data)
@@ -47,6 +46,8 @@ class ParamSerializer(serializers.Serializer):
                 d.update(request.FILES)
             if view is not None and hasattr(view, 'kwargs'):
                 d.update(view.kwargs)
+        if not is_form:
+            d = d.dict()
         super().__init__(instance, d, **kwargs)
         self.is_valid()
 
@@ -154,10 +155,12 @@ class CoolBFFAPIView(APIView, metaclass=ViewMetaclass):
     Backend For Frontend APIView
     """
 
+    logger = logging.getLogger('cool.views')
+
     option_class = APIViewOptions
     SYSTEM_ERROR_STATUS_CODE = cool_settings.API_SYSTEM_ERROR_STATUS_CODE
     PARAM_ERROR_STATUS_CODE = cool_settings.API_PARAM_ERROR_STATUS_CODE
-    SUCCESS_WITH_CODE = cool_settings.API_SUCCESS_WITH_CODE
+    SUCCESS_WITH_CODE_MSG = cool_settings.API_SUCCESS_WITH_CODE_MSG
     SHOW_PARAM_ERROR_INFO = cool_settings.API_SHOW_PARAM_ERROR_INFO
     description_template_name = 'cool/views/api_description.html'
 
@@ -181,7 +184,9 @@ class CoolBFFAPIView(APIView, metaclass=ViewMetaclass):
     @classmethod
     def get_view_info(cls):
         request_info = cls.request_info_data()
-        response_info = ResponseData(cls.response_info_data()).get_response_data()
+        response_info = ResponseData(
+            cls.response_info_data(), success_with_code_msg=cls.SUCCESS_WITH_CODE_MSG
+        ).get_response_data()
         return {
             'request_info': request_info,
             'response_info': response_info,
@@ -210,6 +215,8 @@ class CoolBFFAPIView(APIView, metaclass=ViewMetaclass):
         data = MultiValueDict()
         data.update(request.GET)
         data.update(request.POST)
+        if hasattr(request, 'data'):
+            data.update(request.data)
         data.update(kwargs)
         request.params = Param(self, request, data, request.FILES)
 
@@ -219,7 +226,7 @@ class CoolBFFAPIView(APIView, metaclass=ViewMetaclass):
         if isinstance(context, (Model, QuerySet)) and issubclass(self.response_info_serializer_class, ModelSerializer):
             context = self.response_info_serializer_class(context, many=self.response_many, request=self.request).data
         if not isinstance(context, ResponseData):
-            context = ResponseData(context)
+            context = ResponseData(context, success_with_code_msg=self.SUCCESS_WITH_CODE_MSG)
         return context.get_response()
 
     def check_api_permissions(self, request, *args, **kwargs):
@@ -251,12 +258,6 @@ class CoolBFFAPIView(APIView, metaclass=ViewMetaclass):
                 data['errors'] = exc_data
         return data
 
-    def get_uncaught_exception_response(self, exc, context):
-        if settings.DEBUG:
-            return None
-        logger.error("uncaught_exception", exc_info=exc, extra={'request': self.request})
-        return self.get_response(ResponseData(None, ErrorCode.ERROR_SYSTEM, status_code=self.SYSTEM_ERROR_STATUS_CODE))
-
     def get_exception_handler(self):
         super_exception_handler = super().get_exception_handler()
 
@@ -277,3 +278,63 @@ class CoolBFFAPIView(APIView, metaclass=ViewMetaclass):
         if isinstance(exc, CoolAPIException):
             return self.get_response(exc.response_data)
         return super().handle_exception(exc)
+
+    def initial(self, request, *args, **kwargs):
+        self.log_request(request, *args, **kwargs)
+        return super().initial(request, *args, **kwargs)
+
+    def finalize_response(self, request, response, *args, **kwargs):
+        response = super().finalize_response(request, response, *args, **kwargs)
+        self.log_response(request, response, *args, **kwargs)
+        return response
+
+    def get_uncaught_exception_response(self, exc, context):
+        self.log_exception(self.request, exc, context)
+        if settings.DEBUG:
+            return None
+        return self.get_response(ResponseData(None, ErrorCode.ERROR_SYSTEM, status_code=self.SYSTEM_ERROR_STATUS_CODE))
+
+    def log_request(self, request, *args, **kwargs):
+        import uuid
+        request.start_time = time.time()
+        request.uid = uuid.uuid4().hex
+        self.logger.info(
+            "request start %s %s %s %s %s %s",
+            request.method,
+            request.get_raw_uri(),
+            request.uid,
+            request.user,
+            request.data,
+            request.META
+        )
+
+    def log_response(self, request, response, *args, **kwargs):
+        data = response.content
+        if response.status_code == 200 and len(data) > 1024:
+            data = data[:1000]
+        self.logger.info(
+            "request finish %ss %s %s %s %s %s %s %s %s",
+            time.time() - getattr(request, 'start_time', 0),
+            request.method,
+            request.get_raw_uri(),
+            getattr(request, 'uid', ''),
+            response.status_code,
+            data,
+            request.user,
+            request.data,
+            request.META
+        )
+
+    def log_exception(self, request, exc, context):
+        self.logger.info(
+            "request exception %ss %s %s %s %s %s %s",
+            time.time() - getattr(request, 'start_time', 0),
+            request.method,
+            request.get_raw_uri(),
+            getattr(request, 'uid', ''),
+            request.user,
+            request.data,
+            request.META,
+            exc_info=exc,
+            extra={'request': request}
+        )
